% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/paws.R
\name{appstream}
\alias{appstream}
\title{Amazon AppStream}
\usage{
appstream(config = list())
}
\arguments{
\item{config}{Optional configuration of credentials, endpoint, and/or region.}
}
\value{
A client for the service. You can call the service's operations using
syntax like \code{svc$operation(...)}, where \code{svc} is the name you've assigned
to the client. The available operations are listed in the
Operations section.
}
\description{
Amazon AppStream 2.0

This is the \emph{Amazon AppStream 2.0 API Reference}. This documentation
provides descriptions and syntax for each of the actions and data types
in AppStream 2.0. AppStream 2.0 is a fully managed, secure application
streaming service that lets you stream desktop applications to users
without rewriting applications. AppStream 2.0 manages the AWS resources
that are required to host and run your applications, scales
automatically, and provides access to your users on demand.

You can call the AppStream 2.0 API operations by using an interface VPC
endpoint (interface endpoint). For more information, see \href{https://docs.aws.amazon.com/appstream2/latest/developerguide/access-api-cli-through-interface-vpc-endpoint.html}{Access AppStream 2.0 API Operations and CLI Commands Through an Interface VPC Endpoint}
in the \emph{Amazon AppStream 2.0 Administration Guide}.

To learn more about AppStream 2.0, see the following resources:
\itemize{
\item \href{https://aws.amazon.com/appstream2/}{Amazon AppStream 2.0 product page}
\item \href{https://docs.aws.amazon.com/appstream2/index.html}{Amazon AppStream 2.0 documentation}
}
}
\section{Service syntax}{
\preformatted{svc <- appstream(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string"
    ),
    endpoint = "string",
    region = "string"
  )
)
}
}

\section{Operations}{

\tabular{ll}{
\link[=appstream_associate_fleet]{associate_fleet} \tab Associates the specified fleet with the specified stack\cr
\link[=appstream_batch_associate_user_stack]{batch_associate_user_stack} \tab Associates the specified users with the specified stacks\cr
\link[=appstream_batch_disassociate_user_stack]{batch_disassociate_user_stack} \tab Disassociates the specified users from the specified stacks\cr
\link[=appstream_copy_image]{copy_image} \tab Copies the image within the same region or to a new region within the same AWS account\cr
\link[=appstream_create_directory_config]{create_directory_config} \tab Creates a Directory Config object in AppStream 2\cr
\link[=appstream_create_fleet]{create_fleet} \tab Creates a fleet\cr
\link[=appstream_create_image_builder]{create_image_builder} \tab Creates an image builder\cr
\link[=appstream_create_image_builder_streaming_url]{create_image_builder_streaming_url} \tab Creates a URL to start an image builder streaming session\cr
\link[=appstream_create_stack]{create_stack} \tab Creates a stack to start streaming applications to users\cr
\link[=appstream_create_streaming_url]{create_streaming_url} \tab Creates a temporary URL to start an AppStream 2\cr
\link[=appstream_create_usage_report_subscription]{create_usage_report_subscription} \tab Creates a usage report subscription\cr
\link[=appstream_create_user]{create_user} \tab Creates a new user in the user pool\cr
\link[=appstream_delete_directory_config]{delete_directory_config} \tab Deletes the specified Directory Config object from AppStream 2\cr
\link[=appstream_delete_fleet]{delete_fleet} \tab Deletes the specified fleet\cr
\link[=appstream_delete_image]{delete_image} \tab Deletes the specified image\cr
\link[=appstream_delete_image_builder]{delete_image_builder} \tab Deletes the specified image builder and releases the capacity\cr
\link[=appstream_delete_image_permissions]{delete_image_permissions} \tab Deletes permissions for the specified private image\cr
\link[=appstream_delete_stack]{delete_stack} \tab Deletes the specified stack\cr
\link[=appstream_delete_usage_report_subscription]{delete_usage_report_subscription} \tab Disables usage report generation\cr
\link[=appstream_delete_user]{delete_user} \tab Deletes a user from the user pool\cr
\link[=appstream_describe_directory_configs]{describe_directory_configs} \tab Retrieves a list that describes one or more specified Directory Config objects for AppStream 2\cr
\link[=appstream_describe_fleets]{describe_fleets} \tab Retrieves a list that describes one or more specified fleets, if the fleet names are provided\cr
\link[=appstream_describe_image_builders]{describe_image_builders} \tab Retrieves a list that describes one or more specified image builders, if the image builder names are provided\cr
\link[=appstream_describe_image_permissions]{describe_image_permissions} \tab Retrieves a list that describes the permissions for shared AWS account IDs on a private image that you own\cr
\link[=appstream_describe_images]{describe_images} \tab Retrieves a list that describes one or more specified images, if the image names or image ARNs are provided\cr
\link[=appstream_describe_sessions]{describe_sessions} \tab Retrieves a list that describes the streaming sessions for a specified stack and fleet\cr
\link[=appstream_describe_stacks]{describe_stacks} \tab Retrieves a list that describes one or more specified stacks, if the stack names are provided\cr
\link[=appstream_describe_usage_report_subscriptions]{describe_usage_report_subscriptions} \tab Retrieves a list that describes one or more usage report subscriptions\cr
\link[=appstream_describe_users]{describe_users} \tab Retrieves a list that describes one or more specified users in the user pool\cr
\link[=appstream_describe_user_stack_associations]{describe_user_stack_associations} \tab Retrieves a list that describes the UserStackAssociation objects\cr
\link[=appstream_disable_user]{disable_user} \tab Disables the specified user in the user pool\cr
\link[=appstream_disassociate_fleet]{disassociate_fleet} \tab Disassociates the specified fleet from the specified stack\cr
\link[=appstream_enable_user]{enable_user} \tab Enables a user in the user pool\cr
\link[=appstream_expire_session]{expire_session} \tab Immediately stops the specified streaming session\cr
\link[=appstream_list_associated_fleets]{list_associated_fleets} \tab Retrieves the name of the fleet that is associated with the specified stack\cr
\link[=appstream_list_associated_stacks]{list_associated_stacks} \tab Retrieves the name of the stack with which the specified fleet is associated\cr
\link[=appstream_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves a list of all tags for the specified AppStream 2\cr
\link[=appstream_start_fleet]{start_fleet} \tab Starts the specified fleet\cr
\link[=appstream_start_image_builder]{start_image_builder} \tab Starts the specified image builder\cr
\link[=appstream_stop_fleet]{stop_fleet} \tab Stops the specified fleet\cr
\link[=appstream_stop_image_builder]{stop_image_builder} \tab Stops the specified image builder\cr
\link[=appstream_tag_resource]{tag_resource} \tab Adds or overwrites one or more tags for the specified AppStream 2\cr
\link[=appstream_untag_resource]{untag_resource} \tab Disassociates one or more specified tags from the specified AppStream 2\cr
\link[=appstream_update_directory_config]{update_directory_config} \tab Updates the specified Directory Config object in AppStream 2\cr
\link[=appstream_update_fleet]{update_fleet} \tab Updates the specified fleet\cr
\link[=appstream_update_image_permissions]{update_image_permissions} \tab Adds or updates permissions for the specified private image\cr
\link[=appstream_update_stack]{update_stack} \tab Updates the specified fields for the specified stack
}
}

\examples{
\dontrun{
svc <- appstream()
svc$associate_fleet(
  Foo = 123
)
}

}
